@@ -1,6 +1,8 @@
 from sky_api_client.entity.base import Entity
+from sky_api_client.entity.registry import EntityRegistry
 
 
+@EntityRegistry.register('address')
 class Address(Entity):
     LIST_URL = '/constituent/v1/addresses/'
     CREATE_URL = '/constituent/v1/addresses/'
