@@ -1,6 +1,8 @@
 from sky_api_client.entity.base import Entity
+from sky_api_client.entity.registry import EntityRegistry
 
 
+@EntityRegistry.register('online_presence')
 class OnlinePresence(Entity):
     LIST_URL = '/constituent/v1/onlinepresences?include_inactive=true'
     CREATE_URL = '/constituent/v1/onlinepresences/'
