@@ -1,6 +1,8 @@
 from sky_api_client.entity.base import Entity
+from sky_api_client.entity.registry import EntityRegistry
 
 
+@EntityRegistry.register('phone')
 class Phone(Entity):
     LIST_URL = '/constituent/v1/phones/'
     CREATE_URL = '/constituent/v1/phones/'
